@@ -12,6 +12,7 @@ class Hub(models.Model):
     type = models.CharField(max_length=255, null=True)
     display_name = models.CharField(max_length=255, null=True)
     aid = models.IntegerField()
+    keep_statistics = models.BooleanField(null=True, blank=True, default=False)
 
     updated_at = models.DateTimeField(auto_now=True)
     created_at = models.DateTimeField(auto_now_add=True)
@@ -274,6 +275,111 @@ class HardwareConfig(models.Model):
             models.Index(fields=['id', 'hardware']),
         ]
 
+class HardwareStats(models.Model):
+    id = models.UUIDField(primary_key=True, default=uuid.uuid4)
+    hardwares = models.ForeignKey(Hardware, on_delete=models.CASCADE, blank=True, null=True, default=None)
+    type = models.CharField(max_length=255, null=True)
+    value = models.FloatField(null=True)
+    updated_at = models.DateTimeField(auto_now=True)
+    created_at = models.DateTimeField(auto_now_add=True)
+
+    def save(self, *args, **kwargs):
+        if not self.created_at:
+            self.created_at = timezone.now()
+        self.updated_at = timezone.now()
+
+        return super().save(*args, **kwargs)
+
+    class Meta:
+        indexes = [
+            models.Index(fields=['id', 'hardware']),
+        ]
+
+
+
+
+class DataTransformer(models.Model):
+    id = models.UUIDField(primary_key=True, default=uuid.uuid4)
+    accessory = place = models.OneToOneField(
+        Accessory,
+        on_delete=models.CASCADE
+    )
+    data_transformer_parent = models.ForeignKey('self', on_delete=models.CASCADE, blank=True, null=True, default=None)
+    data_transformer_child = models.ForeignKey('self', on_delete=models.CASCADE, blank=True, null=True, default=None)
+
+    def save(self, *args, **kwargs):
+        if not self.created_at:
+            self.created_at = timezone.now()
+        self.updated_at = timezone.now()
+
+        return super().save(*args, **kwargs)
+
+    class Meta:
+        indexes = [
+            models.Index(fields=['id','accessory']),
+        ]
+
+
+class DataTransformerConstants(models.Model):
+    id = models.UUIDField(primary_key=True, default=uuid.uuid4)
+    data_transformer = models.ForeignKey(DataTransformer, on_delete=models.CASCADE, blank=True, null=True, default=None)
+    type = models.CharField(max_length=255, null=True)
+    index = models.IntegerField()
+    value = models.FloatField(null=True)
+    updated_at = models.DateTimeField(auto_now=True)
+    created_at = models.DateTimeField(auto_now_add=True)
+
+    def save(self, *args, **kwargs):
+        if not self.created_at:
+            self.created_at = timezone.now()
+        self.updated_at = timezone.now()
+
+        return super().save(*args, **kwargs)
+
+    class Meta:
+        indexes = [
+            models.Index(fields=['id','data_transformer']),
+        ]
+
+class HardwareDataTransformer(models.Model):
+    id = models.UUIDField(primary_key=True, default=uuid.uuid4)
+    hardware = models.ForeignKey(Hardware, on_delete=models.CASCADE, blank=True, null=True, default=None)
+    data_transformer = models.ForeignKey(DataTransformer,on_delete=models.CASCADE, blank=True, null=True, default=None)
+    index = models.IntegerField()
+    updated_at = models.DateTimeField(auto_now=True)
+    created_at = models.DateTimeField(auto_now_add=True)
+
+    def save(self, *args, **kwargs):
+        if not self.created_at:
+            self.created_at = timezone.now()
+        self.updated_at = timezone.now()
+
+        return super().save(*args, **kwargs)
+
+    class Meta:
+        indexes = [
+            models.Index(fields=['id','data_transformer','hardware']),
+        ]
+
+class HardwareStatsDataTransformer(models.Model):
+    id = models.UUIDField(primary_key=True, default=uuid.uuid4)
+    hardware_stat = models.ForeignKey(HardwareStats, on_delete=models.CASCADE, blank=True, null=True, default=None)
+    data_transformer = models.ForeignKey(DataTransformer,on_delete=models.CASCADE, blank=True, null=True, default=None)
+    index = models.IntegerField()
+    updated_at = models.DateTimeField(auto_now=True)
+    created_at = models.DateTimeField(auto_now_add=True)
+
+    def save(self, *args, **kwargs):
+        if not self.created_at:
+            self.created_at = timezone.now()
+        self.updated_at = timezone.now()
+
+        return super().save(*args, **kwargs)
+
+    class Meta:
+        indexes = [
+            models.Index(fields=['id','data_transformer']),
+        ]
 
 class Calibration(models.Model):
     id = models.UUIDField(primary_key=True, default=uuid.uuid4)
